<?php
/**
 * Front functions
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */


namespace DDWCWalletManagement\Includes\Front;

use DDWCWalletManagement\Helper\Rules\DDWCWM_Rules_Helper;
use DDWCWalletManagement\Helper\Transactions\DDWCWM_Transactions_Helper;
use DDWCWalletManagement\Helper\Users\DDWCWM_Users_Helper;
use DDWCWalletManagement\Templates\Front;

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'DDWCWM_Front_Functions' ) ) {
	/**
	 * Front functions class
	 */
	class DDWCWM_Front_Functions {

		/**
		 * Add Wallet Menu in my account page function
		 *
		 * @param array $items
		 * @return array
		 */
		public function ddwcwm_add_woocommerce_menu( $items ) {
			global $ddwcwm_wallet;

			$customer_logout_endpoint = get_option( 'woocommerce_logout_endpoint', 'customer-logout' );

			// Remove the logout menu item.
			$logout = $items[ $customer_logout_endpoint ];
			unset( $items[ $customer_logout_endpoint ] );

			if ( apply_filters( 'ddwcwm_display_myaccounts_menu', true ) ) {
				// Insert your custom endpoint.
				$items[ $ddwcwm_wallet[ 'my_account_endpoint' ] ] = $ddwcwm_wallet[ 'my_account_endpoint_title' ];
			}

			// Insert back the logout item.
			if ( ! empty( $logout ) ) {
				$items[ $customer_logout_endpoint ] = $logout;
			}
			return $items;
		}

		/**
		 * Add Query Vars function
		 *
		 * @param array $vars
		 * @return array
		 */
		public function ddwcwm_add_query_vars( $vars ) {
			global $ddwcwm_wallet;
			$vars[] = $ddwcwm_wallet[ 'my_account_endpoint' ];
            return $vars;
		}

		/**
		 * Add Wallet Content on my account page function
		 *
		 * @return void
		 */
		public function ddwcwm_add_wallet_content_on_my_account_page() {
			global $wp_query, $ddwcwm_wallet;

			$page = $wp_query->query_vars[ $ddwcwm_wallet[ 'my_account_endpoint' ] ];

            if ( strpos( $page, 'view' ) !== false ) {
                $id = preg_replace( "/[^0-9]/", '', $page );

                if ( ! empty( $id ) && is_numeric( $id ) && $id > 0 ) {
					$id = intval( $id );

					$transaction_helper = new DDWCWM_Transactions_Helper();

					$transaction_helper->ddwcwm_get_transaction_template( $id );
                }
            } else {
                new Front\MyAccount\DDWCWM_My_Wallet_Template();
            }
		}

		/**
		 * Remove Sidebar from wallet menu function
		 *
		 * @param array $sidebars_widgets
		 * @return array
		 */
		public function ddwcwm_remove_sidebar_from_wallet_page( $sidebars_widgets ) {
            global $wp_query, $ddwcwm_wallet;
			return isset( $wp_query->query_vars[ $ddwcwm_wallet[ 'my_account_endpoint' ] ] ) && empty( $ddwcwm_wallet[ 'enable_widgets_my_account_endpoint' ] ) && is_account_page() ? [ false ] : $sidebars_widgets;
		}

		/**
		 * Register front scripts function
		 *
		 * @return void
		 */
		public function ddwcwm_register_front_scripts() {
			global $ddwcwm_wallet;
			wp_register_style( 'ddwcwm-front-style', DDWCWM_PLUGIN_URL . 'assets/css/style.css', [], DDWCWM_SCRIPT_VERSION );
			wp_register_script( 'ddwcwm-front-script', DDWCWM_PLUGIN_URL . 'assets/js/front.js', [], DDWCWM_SCRIPT_VERSION );

			wp_localize_script( 'ddwcwm-front-script', 'ddwcwmFrontObj', [
				'ajaxUrl'       => admin_url( 'admin-ajax.php' ),
				'ajaxNonce'     => wp_create_nonce( 'ddwcwm-nonce' ),
				'ddwcwm_wallet' => $ddwcwm_wallet,
				'i18n'          => [
					'enterOtp' => esc_html__( 'Enter OTP first!!', 'ddwc-wallet-management' ),
					'demoOtp'  => esc_html__( 'Demo OTP', 'ddwc-wallet-management' ),
				],
			] );			
		}

		/**
		 * Enqueue front scripts function
		 *
		 * @return void
		 */
		public function ddwcwm_enqueue_front_scripts() {
			wp_enqueue_style( 'ddwcwm-front-style' );
			wp_enqueue_script( 'ddwcwm-front-script' );
		}

		/**
		 * Display notice if dues product exists in cart function
		 *
		 * @return void
		 */
		public function ddwcwm_display_notice_if_wallet_topup_added_in_cart() {
			$wallet_topup_pro = get_page_by_path( 'ddwcwm-wallet-topup' , OBJECT, 'product' );

			if ( is_shop() || is_single() ) {
				$cart_contents = WC()->cart->cart_contents;

				if ( ! empty( $cart_contents ) ) {
					foreach( $cart_contents as $key => $cart_content ) {
						if ( $cart_content[ 'product_id' ] == $wallet_topup_pro->ID ) {
							wc_add_notice( esc_html__( 'Cannot add new products now. Either empty cart or process wallet topup first.', 'ddwc-wallet-management' ), 'notice' );
						}
					}
				}
			}
		}

		/**
		 * Check if dues product exist in cart function
		 * 
		 * @param mixed
		 * @return mixed
		 */
		public function ddwcwm_check_if_wallet_topup_product_exists_in_cart( $cart_item_data ) {
			$wallet_topup_pro = get_page_by_path( 'ddwcwm-wallet-topup' , OBJECT, 'product' );

			$wallet_pro_id = $wallet_topup_pro->ID;

			$cart_contents = WC()->cart->cart_contents;

			if ( ! empty( $cart_contents ) ) {

				$wallet_product_in_cart_check = 0;
                $nonwallet_products_in_cart   = [];

                foreach ( $cart_contents as $cart_item_key => $cart_content ) {
					$id = ! empty( $cart_content[ 'variation_id' ] ) ? $cart_content[ 'variation_id' ] : $cart_content[ 'product_id' ];

					if ( $id == $wallet_pro_id ) {
                        $wallet_product_in_cart_check = 1;
                    } else {
                        $nonwallet_products_in_cart[ $id ] = $cart_item_key;
					}
				}

				if ( $wallet_product_in_cart_check && ! empty( $nonwallet_products_in_cart ) ) {
					foreach( $nonwallet_products_in_cart as $product_id => $cart_item_key ) {
						WC()->cart->remove_cart_item( $cart_item_key );
					}
				}
			}

			return $cart_item_data;
		}

		/**
         * This function handles checkout payment gateways.
         *
         * @param array $available_gateways All available gateways.
		 * @return array
         */
		public function ddwcwm_remove_payment_gateway( $available_gateways ) {
			global $ddwcwm_wallet, $wp;

			$wallet_topup_pro = get_page_by_path( 'ddwcwm-wallet-topup' , OBJECT, 'product' );
			$user_helper      = new DDWCWM_Users_Helper();
			$wallet_balance   = $user_helper->ddwcwm_get_user_wallet_balance();

			if ( ! empty( $wp->query_vars[ 'order-pay' ] ) ) {
				$order_id    = absint( $wp->query_vars[ 'order-pay' ] );
				$order       = wc_get_order( $order_id );
				$cart_total  = $order->get_total();
				$order_items = $order->get_items();

				foreach ( $order_items as $key => $order_item ) {
					if ( $order_item->get_data()[ 'product_id' ] == $wallet_topup_pro->ID ) {
						foreach ( $available_gateways as $payment_gateway_id => $available_gateway ) {
							if ( ! empty( $ddwcwm_wallet[ 'enabled_payment_gateways' ] ) && ! in_array( $payment_gateway_id, $ddwcwm_wallet[ 'enabled_payment_gateways' ] ) ) {
								unset( $available_gateways[ $payment_gateway_id ] );
							}
						}
						unset( $available_gateways[ 'ddwcwm_wallet' ] );
						break;
					}
				}
			} else {
				$cart_contents = WC()->cart->cart_contents;
				$cart_total    = WC()->cart->total;

				if ( ! empty( $cart_contents ) ) {
					foreach( $cart_contents as $key => $cart_content ) {
						if ( $cart_content[ 'product_id' ] == $wallet_topup_pro->ID ) {
							foreach ( $available_gateways as $payment_gateway_id => $available_gateway ) {
								if ( ! empty( $ddwcwm_wallet[ 'enabled_payment_gateways' ] ) && ! in_array( $payment_gateway_id, $ddwcwm_wallet[ 'enabled_payment_gateways' ] ) ) {
									unset( $available_gateways[ $payment_gateway_id ] );
								}
							}
							unset( $available_gateways[ 'ddwcwm_wallet' ] );
							break;
						}
					}
				}
			}

			$cart_total = apply_filters( 'ddwcwm_modify_amount_to_base_currency', $cart_total );

			if ( 'percentage' === $ddwcwm_wallet[ 'debit_limit_type' ] ) {
                $ddwcwm_wallet[ 'min_debit_limit' ] = floatval( $ddwcwm_wallet[ 'min_debit_limit' ] ) * floatval( $cart_total ) / 100;
                $ddwcwm_wallet[ 'max_debit_limit' ] = floatval( $ddwcwm_wallet[ 'max_debit_limit' ] ) * floatval( $cart_total ) / 100;
            }

			if ( apply_filters( 'ddwcwm_add_custom_conditions_to_remove_wallet_payment_gateway', true, $available_gateways ) && ( $wallet_balance <= 0 || ( ! empty( WC()->session ) && ! empty( WC()->session->get( 'ddwcwm_wallet_amount' ) ) ) || $wallet_balance < $cart_total || ( ! empty( $ddwcwm_wallet[ 'max_debit_limit' ] ) && $ddwcwm_wallet[ 'max_debit_limit' ] < $cart_total ) ) ) {
				unset( $available_gateways[ 'ddwcwm_wallet' ] );
			}

            return $available_gateways;
		}

		/**
		 * Display Wallet Template at Checkout function
		 *
		 * @return void
		 */
		public function ddwcwm_add_wallet_template_on_checkout_page() {
			if ( is_checkout() ) {
				$this->ddwcwm_enqueue_front_scripts();
				new Front\Checkout\DDWCWM_Wallet_Checkout_Template();
			}
		}

		/**
		 * Add Wallet Fee in cart function
		 *
		 * @return void
		 */
		public function ddwcwm_add_wallet_as_fee_in_cart() {
			if ( is_checkout() ) {
				$wallet_amount = WC()->session->get( 'ddwcwm_wallet_amount' );

				$wallet_amount = apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $wallet_amount );

				if ( ! empty( $wallet_amount ) ) {
					if ( ! empty( WC()->cart ) ) {
						WC()->cart->fees_api()->add_fee( [
							'id'        => 'ddwcwm_wallet_fee',
							'name'      => esc_html__( 'Payment via Wallet', 'ddwc-wallet-management' ),
							'amount'    => -$wallet_amount,
							'taxable'   => false,
							'tax_class' => 'non-taxable',
						] );
					}
				}
			} else {
				if ( apply_filters( 'ddwcwm_unset_wallet_session_if_not_checkout_page', true ) ) {
					WC()->session->__unset( 'ddwcwm_wallet_amount' );
				}
			}
		}

		/**
		 * Add remove wallet button on checkout page function
		 *
		 * @param string $cart_totals_fee_html
		 * @param object $fee
		 * @return string
		 */
		public function ddwcwm_add_remove_wallet_button_on_checkout( $cart_totals_fee_html, $fee ) {
			if ( 'ddwcwm_wallet_fee' === $fee->id ) {
				$this->ddwcwm_enqueue_front_scripts();
				ob_start();
				?>
				<a href="#" id="ddwcwm-remove-wallet"><?php esc_html_e( 'Remove', 'ddwc-wallet-management' ); ?></a>
				<?php
				$remove_button = ob_get_contents();
				ob_end_clean();
				$cart_totals_fee_html .= $remove_button;
			}

			return $cart_totals_fee_html;
		}

		/**
		 * Remove used wallet amount from user meta function
		 *
		 * @param int $order_id
		 * @return void
		 */
		public function ddwcwm_deduct_wallet_amount_on_order_processed( $order_id ) {
			global $ddwcwm_wallet;

			$used_wallet_amount = WC()->session->get( 'ddwcwm_wallet_amount' );

			if ( ! empty( $used_wallet_amount ) ) {
				WC()->session->__unset( 'ddwcwm_wallet_amount' );

				$user_id = get_current_user_id();

				$user_helper = new DDWCWM_Users_Helper();

				$user_wallet_balance = $user_helper->ddwcwm_get_user_wallet_balance();

				$new_wallet_balance = $user_wallet_balance - $used_wallet_amount;

				$user_helper->ddwcwm_set_user_wallet_balance( $new_wallet_balance, $user_id );

				do_action( 'ddwcwm_after_deduct_wallet_fee', $used_wallet_amount, $user_id, $order_id );

				$data = [
					'type'      => 'debit',
					'amount'    => $used_wallet_amount,
					'user_id'   => $user_id,
					'order_id'  => $order_id,
					'note'      => esc_html__( 'Debited on using it on purchase.', 'ddwc-wallet-management' ),
					'date'      => current_time( 'Y-m-d H:i:s' ),
					'reference' => 'order_debit',
				];

				$transaction_helper = new DDWCWM_Transactions_Helper();

				$transaction_helper->ddwcwm_save_transaction( $data );

				$email_message = [];

				$email_message[] = sprintf( esc_html__( 'You have used %s from your Wallet balance for order #%s.', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $used_wallet_amount ) ), $order_id );

				$email_message[] = sprintf( esc_html__( 'Remaining Wallet balance is %s.', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $new_wallet_balance ) ) );

				$email_data = [
					'email'   => get_userdata( $user_id )->user_email,
					'message' => $email_message
				];

				do_action( 'ddwcwm_mail', $email_data );

				update_post_meta( $order_id, '_ddwcwm_wallet_amount_used', $used_wallet_amount );
			}

			$rules_helper = new DDWCWM_Rules_Helper();

			$awarded_cashback_data = $rules_helper->ddwcwm_calculate_cashbacks_with_order( $order_id );

			if ( ! empty( $awarded_cashback_data ) ) {
				update_post_meta( $order_id, '_ddwcwm_awarded_cashback_data', $awarded_cashback_data );
			}

			$order            = wc_get_order( $order_id );
			$order_items      = $order->get_items();
			$wallet_topup_pro = get_page_by_path( 'ddwcwm-wallet-topup' , OBJECT, 'product' );

			foreach ( $order_items as $key => $order_item ) {
				if ( $order_item->get_data()[ 'product_id' ] == $wallet_topup_pro->ID && $ddwcwm_wallet[ 'topup_order_status' ] === 'completed' ) {
					$order->update_status( 'completed' );
				}
			}
		}

		/**
		 * WooCommerce before calculate totals function
		 *
		 * @return void
		 */
		public function ddwcwm_woocommerce_before_calculate_totals() {
			$cart_contents = WC()->cart->get_cart_contents();
			$topup_amount  = WC()->session->get( 'ddwcwm_wallet_topup_amount' );

			if ( ! empty( $cart_contents ) && ! empty( $topup_amount ) && apply_filters( 'ddwcwm_do_normal_topup', true ) ) {
				foreach ( $cart_contents as $key => $cart_content ) {
					$id               = ! empty( $cart_content[ 'variation_id' ] ) ? $cart_content[ 'variation_id' ] : $cart_content[ 'product_id' ];
					$wallet_topup_pro = get_page_by_path( 'ddwcwm-wallet-topup' , OBJECT, 'product' );

					if ( $wallet_topup_pro->ID == $id ) {
						$cart_content[ 'data' ]->set_price( $topup_amount );
					}
				}
			}
		}

		/**
		 * Handle wallet topup function
		 *
		 * @return void
		 */
		public function ddwcwm_handle_wallet_topup() {
			global $ddwcwm_wallet;

			if ( isset( $_POST[ 'ddwcwm_wallet_topup' ] ) && ! empty( $_POST[ 'ddwcwm_wallet_topup_nonce' ] ) && wp_verify_nonce( $_POST[ 'ddwcwm_wallet_topup_nonce' ], 'ddwcwm_wallet_topup_nonce_action' ) ) {
				$topup_amount = ! empty( $_POST[ 'ddwcwm_wallet_topup_amount' ] ) ? floatval( $_POST[ 'ddwcwm_wallet_topup_amount' ] ) : 0;

				if ( ! empty( $topup_amount ) ) {
					$topup_amount = apply_filters( 'ddwcwm_modify_amount_to_base_currency', $topup_amount );

					if ( $ddwcwm_wallet[ 'min_topup_limit' ] == '' || $topup_amount >= $ddwcwm_wallet[ 'min_topup_limit' ] ) {
						if ( $ddwcwm_wallet[ 'max_topup_limit' ] == '' || $topup_amount <= $ddwcwm_wallet[ 'max_topup_limit' ] ) {
							if ( apply_filters( 'ddwcwm_do_normal_topup', true ) ) {
								if ( ! empty( WC()->session ) && is_object( WC()->session ) ) {
									WC()->session->set( 'ddwcwm_wallet_topup_amount', $topup_amount );
								}
								$wallet_topup_pro = get_page_by_path( 'ddwcwm-wallet-topup' , OBJECT, 'product' );
								// update_post_meta( $wallet_topup_pro->ID, '_price', $topup_amount );
								WC()->cart->empty_cart();
								WC()->cart->add_to_cart( $wallet_topup_pro->ID );
							} else {
								do_action( 'ddwcwm_add_other_topup_functionality', $topup_amount );
							}
							wp_safe_redirect( wc_get_cart_url() );
							exit();
						} else {
							wc_add_notice( sprintf( esc_html__( 'Enter topup amount less than the max topup limit of %s', 'ddwc-wallet-management' ), wc_price( $ddwcwm_wallet[ 'max_topup_limit' ] ) ), 'error' );

							wp_safe_redirect( $_SERVER[ 'HTTP_REFERER' ] );
							exit();
						}
					} else {
						wc_add_notice( sprintf( esc_html__( 'Enter topup amount more than the min topup limit of %s', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'min_topup_limit' ] ) ) ), 'error' );

						wp_safe_redirect( $_SERVER[ 'HTTP_REFERER' ] );
						exit();
					}
				} else {
					wc_add_notice( esc_html__( 'Enter amount to topup', 'ddwc-wallet-management' ), 'error' );
					wp_safe_redirect( $_SERVER[ 'HTTP_REFERER' ] );
					exit();
				}
			}
		}

		/**
		 * Add Wallet balance shortcode content function
		 * 
		 * @return void
		 */
		public function ddwcwm_add_wallet_balance_shortcode_content() {
			$this->ddwcwm_enqueue_front_scripts();
			ob_start();
			require DDWCWM_PLUGIN_FILE . 'templates/shortcodes/wallet-balance.php';
			return ob_get_clean();
		}

		/**
		 * Add Wallet balance layout shortcode content function
		 * 
		 * @return void
		 */
		public function ddwcwm_add_wallet_balance_layout_shortcode_content() {
			$this->ddwcwm_enqueue_front_scripts();
			ob_start();
			require DDWCWM_PLUGIN_FILE . 'templates/shortcodes/wallet-balance-layout.php';
			return ob_get_clean();
		}

		/**
		 * Add Wallet operations shortcode content function
		 * 
		 * @return void
		 */
		public function ddwcwm_add_wallet_operations_shortcode_content() {
			$this->ddwcwm_enqueue_front_scripts();
			ob_start();
			require DDWCWM_PLUGIN_FILE . 'templates/shortcodes/wallet-operations.php';
			return ob_get_clean();
		}

		/**
		 * Add Wallet balance & operations shortcode content function
		 * 
		 * @return void
		 */
		public function ddwcwm_add_wallet_balance_operations_shortcode_content() {
			global $ddwcwm_wallet;
			ob_start();
			?>
			<div class="ddwcwm-wallet-wrapper">
				<?php
                echo do_shortcode( $ddwcwm_wallet[ 'wallet_balance_shortcode' ] );
                echo do_shortcode( $ddwcwm_wallet[ 'wallet_operations_shortcode' ] );
                ?>
			</div>
			<?php
			return ob_get_clean();
		}

		/**
		 * Add Wallet transactions shortcode content function
		 * 
		 * @return void
		 */
		public function ddwcwm_add_wallet_transactions_shortcode_content() {
			$this->ddwcwm_enqueue_front_scripts();
			ob_start();
			require DDWCWM_PLUGIN_FILE . 'templates/shortcodes/wallet-transactions.php';
			return ob_get_clean();
		}

		/**
         * Unset Fee tax for partial amount
         * @param array $fee_taxes
         * @param object $fee
         * @return array
         */
        public function ddwcwm_remove_tax_from_wallet_fee( $fee_taxes, $fee ) {
			if ( 'ddwcwm_wallet_fee' === $fee->object->id ) {
				$fee->total = floatval( $fee->object->amount ) * 100;
				return [];
			}

			return $fee_taxes;
        }
	}
}
