<?php
/**
 * Cashback Rules template class
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

namespace DDWCWalletManagement\Templates\Admin\Rules;

use DDWCWalletManagement\Helper\Rules\DDWCWM_Rules_Helper;

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'DDWCWM_Cashback_Rules_Template' ) ) {
	/**
	 * Cashback Rules template class
	 */
	class DDWCWM_Cashback_Rules_Template {

        /**
         * Rules Helper variable
         *
         * @var object
         */
        protected $rules_helper;

		/**
		 * Construct
		 */
		public function __construct() {
            $this->rules_helper       = new DDWCWM_Rules_Helper();
            $this->cart_rules_data    = $this->rules_helper->ddwcwm_get_all_cashback_rules();
            $this->product_rules_data = $this->rules_helper->ddwcwm_get_all_product_cashback_rules();

			$this->ddwcwm_save_rules_data();
			$this->ddwcwm_get_manage_rules_template();
        }

        /**
		 * Get Manage Rules Template function
		 *
		 * @return void
		 */
        public function ddwcwm_get_manage_rules_template() {
            $cart_rules_data    = $this->cart_rules_data;
            $product_rules_data = $this->product_rules_data;
            ?>
            <div class="wrap">
				<h1 class="wp-heading-inline"><?php esc_html_e( 'Cashback Rules', 'ddwc-wallet-management' ); ?></h1>
				<hr class="wp-header-end" />
                <div class="ddwcwm-rule-container">
                    <form method="POST" id="ddwcwm-rule-form" novalidate>
                        <div class="ddwcwm-rule-wrap">
                            <h2><?php esc_html_e( 'General', 'ddwc-wallet-management' ); ?></h2>
                            <table class="widefat fixed ddwcwm-general-rule">
                                <thead>
                                    <tr>
                                        <th><strong><?php echo esc_html__( 'Amount From', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'From this amount range, respective cashback applied.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                        <th><strong><?php echo esc_html__( 'Amount To', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'To this amount range, respective cashback applied.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                        <th><strong><?php echo esc_html__( 'Basis', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'Select cashback basis.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                        <th><strong><?php echo esc_html__( 'Cashback Type', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'Select cashback type.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                        <th><strong><?php echo esc_html__( 'Cashback Amount', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'This cashback amount will be credited to customers between the respective amount ranges.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                        <th><strong><?php echo esc_html__( 'Status', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'Select rule status.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php
                                    if ( ! empty( $cart_rules_data ) ) {
                                        foreach ( $cart_rules_data as $key => $cart_rule_data ) {
                                            ?>
                                            <tr valign="top">
                                                <td class="forminp forminp-text">
                                                    <input type="number" name="ddwcwm_amount_from[<?php echo esc_attr( $cart_rule_data[ 'id' ] ); ?>]" class="regular-text ddwcwm-width-90 ddwcwm-amount-from" placeholder="<?php esc_attr_e( 'Enter Amount From', 'ddwc-wallet-management' ); ?>" min="0" step="0.01" value="<?php echo esc_attr( $cart_rule_data[ 'amount_from' ] ); ?>" autocomplete="off" />
                                                    <strong><?php echo esc_html( get_woocommerce_currency_symbol() ); ?></strong>
                                                </td>
                                                <td class="forminp forminp-text">
                                                    <input type="number" name="ddwcwm_amount_to[<?php echo esc_attr( $cart_rule_data[ 'id' ] ); ?>]" class="regular-text ddwcwm-width-90 ddwcwm-amount-to" placeholder="<?php esc_attr_e( 'Enter Amount to', 'ddwc-wallet-management' ); ?>" min="0" step="0.01" value="<?php echo esc_attr( $cart_rule_data[ 'amount_to' ] ); ?>" autocomplete="off" autocomplete="off" />
                                                    <strong><?php echo esc_html( get_woocommerce_currency_symbol() ); ?></strong>
                                                </td>
                                                <td class="forminp forminp-text">
                                                    <select class="ddwcwm-rule-basis" name="ddwcwm_rule_basis[<?php echo esc_attr( $cart_rule_data[ 'id' ] ); ?>]" data-placeholder="<?php esc_attr_e( 'Select Basis', 'ddwc-wallet-management' ); ?>">
                                                        <option value="cart" <?php echo esc_attr( $cart_rule_data[ 'basis' ] === 'cart' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Cart', 'ddwc-wallet-management' ); ?></option>
                                                        <option value="topup" <?php echo esc_attr( $cart_rule_data[ 'basis' ] === 'topup' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Topup', 'ddwc-wallet-management' ); ?></option>
                                                    </select>
                                                </td>
                                                <td class="forminp forminp-text">
                                                    <select class="ddwcwm-cashback-type" name="ddwcwm_cashback_type[<?php echo esc_attr( $cart_rule_data[ 'id' ] ); ?>]" data-placeholder="<?php esc_attr_e( 'Cashback Type', 'ddwc-wallet-management' ); ?>">
                                                        <option value="fixed" <?php echo esc_attr( $cart_rule_data[ 'cashback_type' ] === 'fixed' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Fixed', 'ddwc-wallet-management' ); ?></option>
                                                        <option value="percentage" <?php echo esc_attr( $cart_rule_data[ 'cashback_type' ] === 'percentage' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Percentage', 'ddwc-wallet-management' ); ?></option>
                                                    </select>
                                                </td>
                                                <td class="forminp forminp-text">
                                                    <input type="number" name="ddwcwm_cashback_amount[<?php echo esc_attr( $cart_rule_data[ 'id' ] ); ?>]" class="regular-text ddwcwm-width-90 ddwcwm-cashback-amount" placeholder="<?php esc_attr_e( 'Enter Points Weight', 'ddwc-wallet-management' ); ?>" min="0" step="0.01" value="<?php echo esc_attr( $cart_rule_data[ 'cashback_amount' ] ); ?>" autocomplete="off" />
                                                    <strong><?php echo esc_html( get_woocommerce_currency_symbol() ); ?></strong>
                                                </td>
                                                <td class="forminp forminp-text">
                                                    <select class="ddwcwm-rule-status" name="ddwcwm_rule_status[<?php echo esc_attr( $cart_rule_data[ 'id' ] ); ?>]" data-placeholder="<?php esc_attr_e( 'Select Status', 'ddwc-wallet-management' ); ?>">
                                                        <option value="enabled" <?php echo esc_attr( $cart_rule_data[ 'status' ] === 'enabled' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Enabled', 'ddwc-wallet-management' ); ?></option>
                                                        <option value="disabled" <?php echo esc_attr( $cart_rule_data[ 'status' ] === 'disabled' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Disabled', 'ddwc-wallet-management' ); ?></option>
                                                    </select>
                                                    <span class="dashicons dashicons-trash ddwcwm-remove-general-rule-row" title="<?php esc_attr_e( 'Remove', 'ddwc-wallet-management' ); ?>"></span>
                                                </td>
                                            </tr>
                                            <?php
                                        }
                                    }

                                    ?>
                                    <tr>
                                        <td colspan="6">
                                            <a href="javascript:void(0);" id="ddwcwm-add-general-rule-line" class="button"><?php esc_html_e( 'Add Row', 'ddwc-wallet-management' ); ?></a>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>

                        <div class="ddwcwm-rule-wrap">
                            <h2><?php esc_html_e( 'Products', 'ddwc-wallet-management' ); ?></h2>

                            <table class="widefat fixed ddwcwm-product-rule">
                                <thead>
                                    <tr>
                                        <th><strong><?php echo esc_html__( 'Products', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'Customers will get awarded with the respective cashback if they purchase the selected products.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                        <th><strong><?php echo esc_html__( 'Quantity', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'Enter the quantity for purchase of the selected products after which customers will get awarded with the respective cashback.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                        <th><strong><?php echo esc_html__( 'Cashback Type', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'Enter the cashback type either fixed or percentage.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                        <th><strong><?php echo esc_html__( 'Cashback Amount', 'ddwc-wallet-management' ) . wc_help_tip( esc_html__( 'Enter the cashback amout which will get awarded to customers who purchase the selected products.', 'ddwc-wallet-management' ) ); ?></strong></th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php
                                    if ( ! empty( $product_rules_data ) ) {
                                        foreach ( $product_rules_data as $key => $product_rule_data ) {
                                            $product_id   = $product_rule_data[ 'post_id' ];
                                            $product_rule = maybe_unserialize( $product_rule_data[ 'meta_value' ] );
                                            ?>
                                            <tr valign="top">
                                                <td class="forminp forminp-text">
                                                    <select class="ddwcwm-product-select" name="ddwcwm_rule_products[]" data-placeholder="<?php esc_attr_e( 'Search products', 'ddwc-wallet-management' ); ?>">
                                                        <option value="<?php echo esc_attr( $product_id ); ?>" selected="selected"><?php echo esc_html( get_the_title( $product_id ) ); ?></option>
                                                    </select>
                                                </td>
                                                <td class="forminp forminp-text">
                                                    <input type="number" name="ddwcwm_product_quantity[]" class="regular-text ddwcwm-width-90 ddwcwm-product-quantity" min="0" value="<?php echo esc_attr( $product_rule[ 'quantity' ] ); ?>" autocomplete="off" />
                                                </td>
                                                <td class="forminp forminp-text">
                                                    <select class="ddwcwm-product-cashback-type" name="ddwcwm_product_cashback_type[]" data-placeholder="<?php esc_attr_e( 'Cashback Type', 'ddwc-wallet-management' ); ?>">
                                                        <option value="fixed" <?php echo esc_attr( $product_rule[ 'cashback_type' ] === 'fixed' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Fixed', 'ddwc-wallet-management' ); ?></option>
                                                        <option value="percentage" <?php echo esc_attr( $product_rule[ 'cashback_type' ] === 'percentage' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Percentage', 'ddwc-wallet-management' ); ?></option>
                                                    </select>
                                                </td>
                                                <td class="forminp forminp-text">
                                                    <input type="number" name="ddwcwm_product_cashback[]" class="regular-text ddwcwm-width-90 ddwcwm-product-cashback" min="0" step="0.01" value="<?php echo esc_attr( $product_rule[ 'cashback_amount' ] ); ?>" autocomplete="off" />
                                                    <span class="dashicons dashicons-trash ddwcwm-remove-product-row" title="<?php esc_attr_e( 'Remove', 'ddwc-wallet-management' ); ?>"></span>
                                                </td>
                                            </tr>
                                            <?php
                                        }
                                    }
                                    ?>
                                    <tr>
                                        <td colspan="4">
                                            <a href="javascript:void(0);" id="ddwcwm-add-product-rule-line" class="button"><?php esc_html_e( 'Add Row', 'ddwc-wallet-management' ); ?></a>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>

                        <?php
                        wp_nonce_field( 'ddwcwm_rule_nonce_action', 'ddwcwm_rule_nonce' );
                        submit_button( esc_html__( 'Save', 'ddwc-wallet-management' ), 'primary', 'ddwcwm-save-rule' );
                        ?>
                    </form>

                    <!-- General Cashback Rule Row Template -->
                    <script id="tmpl-ddwcwm-general-rule-row" type="text/html">
                        <tr valign="top">
                            <td class="forminp forminp-text">
                                <input type="number" name="ddwcwm_amount_from[]" class="regular-text ddwcwm-width-90 ddwcwm-amount-from" placeholder="<?php esc_attr_e( 'Enter Amount From', 'ddwc-wallet-management' ); ?>" min="0" step="0.01" autocomplete="off" />
                                <strong><?php echo esc_html( get_woocommerce_currency_symbol() ); ?></strong>
                            </td>
                            <td class="forminp forminp-text">
                                <input type="number" name="ddwcwm_amount_to[]" class="regular-text ddwcwm-width-90 ddwcwm-amount-to" placeholder="<?php esc_attr_e( 'Enter Amount to', 'ddwc-wallet-management' ); ?>" min="0" step="0.01" autocomplete="off" />
                                <strong><?php echo esc_html( get_woocommerce_currency_symbol() ); ?></strong>
                            </td>
                            <td class="forminp forminp-text">
                                <select class="ddwcwm-rule-basis" name="ddwcwm_rule_basis[]" data-placeholder="<?php esc_attr_e( 'Select basis', 'ddwc-wallet-management' ); ?>">
                                    <option value="cart"><?php esc_html_e( 'Cart', 'ddwc-wallet-management' ); ?></option>
                                    <option value="topup"><?php esc_html_e( 'Topup', 'ddwc-wallet-management' ); ?></option>
                                </select>
                            </td>
                            <td class="forminp forminp-text">
                                <select class="ddwcwm-cashback-type" name="ddwcwm_cashback_type[]" data-placeholder="<?php esc_attr_e( 'Select cashback type', 'ddwc-wallet-management' ); ?>">
                                    <option value="fixed"><?php esc_html_e( 'Fixed', 'ddwc-wallet-management' ); ?></option>
                                    <option value="percentage"><?php esc_html_e( 'Percentage', 'ddwc-wallet-management' ); ?></option>
                                </select>
                            </td>
                            <td class="forminp forminp-text">
                                <input type="number" name="ddwcwm_cashback_amount[]" class="regular-text ddwcwm-width-90 ddwcwm-cashback-amount" placeholder="<?php esc_attr_e( 'Enter Cashback Amount', 'ddwc-wallet-management' ); ?>" min="0" step="0.01" autocomplete="off" />
                                <strong><?php echo esc_html( get_woocommerce_currency_symbol() ); ?></strong>
                            </td>
                            <td class="forminp forminp-text">
                                <select class="ddwcwm-rule-status" name="ddwcwm_rule_status[]" data-placeholder="<?php esc_attr_e( 'Select Status', 'ddwc-wallet-management' ); ?>">
                                    <option value="enabled"><?php esc_html_e( 'Enabled', 'ddwc-wallet-management' ); ?></option>
                                    <option value="disabled"><?php esc_html_e( 'Disabled', 'ddwc-wallet-management' ); ?></option>
                                </select>
                                <span class="dashicons dashicons-trash ddwcwm-remove-general-rule-row" title="<?php esc_attr_e( 'Remove', 'ddwc-wallet-management' ); ?>"></span>
                            </td>
                        </tr>
                    </script>

                    <!-- Product Cashback Rule Row Template -->
                    <script id="tmpl-ddwcwm-product-row" type="text/html">
                        <tr valign="top">
                            <td class="forminp forminp-text">
                                <select class="ddwcwm-product-select" name="ddwcwm_rule_products[]" data-placeholder="<?php esc_attr_e( 'Search product', 'ddwc-wallet-management' ); ?>"></select>
                            </td>
                            <td class="forminp forminp-text">
                                <input type="number" name="ddwcwm_product_quantity[]" class="regular-text ddwcwm-width-90 ddwcwm-product-quantity" min="0" autocomplete="off" />
                            </td>
                            <td class="forminp forminp-text">
                                <select class="ddwcwm-product-cashback-type" name="ddwcwm_product_cashback_type[]" data-placeholder="<?php esc_attr_e( 'Cashback Type', 'ddwc-wallet-management' ); ?>">
                                    <option value="fixed"><?php esc_html_e( 'Fixed', 'ddwc-wallet-management' ); ?></option>
                                    <option value="percentage"><?php esc_html_e( 'Percentage', 'ddwc-wallet-management' ); ?></option>
                                </select>
                            </td>
                            <td class="forminp forminp-text">
                                <input type="number" name="ddwcwm_product_cashback[]" class="regular-text ddwcwm-width-90 ddwcwm-product-cashback" min="0" step="0.01" autocomplete="off" />
                                <span class="dashicons dashicons-trash ddwcwm-remove-product-row" title="<?php esc_attr_e( 'Remove', 'ddwc-wallet-management' ); ?>"></span>
                            </td>
                        </tr>
                    </script>

                    <!-- Invalid form data Template -->
                    <script id="tmpl-ddwcwm_form_data_error" type="text/html">
                        <div class='notice notice-error is-dismissible'>
                            <p><?php esc_html_e( 'Some Fields are empty or not valid.', 'ddwc-wallet-management' ); ?></p>
                        </div>
                    </script>
                </div>
            </div>
            <?php
        }

        /**
		 * Save Rules function
		 *
		 * @return void
		 */
        public function ddwcwm_save_rules_data() {
            if ( ! empty( $_POST[ 'ddwcwm-save-rule' ] ) && ! empty( $_POST[ 'ddwcwm_rule_nonce' ] ) && wp_verify_nonce( $_POST[ 'ddwcwm_rule_nonce' ], 'ddwcwm_rule_nonce_action' ) ) {
                if ( $this->rules_helper->ddwcwm_prepare_cashback_rule_data_and_save( $_POST, $this->cart_rules_data, $this->product_rules_data ) ) {
                    $this->cart_rules_data    = $this->rules_helper->ddwcwm_get_all_cashback_rules();
                    $this->product_rules_data = $this->rules_helper->ddwcwm_get_all_product_cashback_rules();
                }
            }
        }
	}
}
