<?php
/**
 * Transaction view template class
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

namespace DDWCWalletManagement\Templates\Admin\Transactions;

use DDWCWalletManagement\Helper\Transactions\DDWCWM_Transactions_Helper;

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'DDWCWM_Transaction_View_Template' ) ) {
	/**
	 * Transaction view template class
	 */
	class DDWCWM_Transaction_View_Template {

        /**
         * Constructor
         *
         * @param array $transaction
         */
		public function __construct( $transaction ) {
			$this->ddwcwm_get_transaction_view_template( $transaction );
        }

        /**
		 * Get Transaction view template function
		 *
         * @param array $transaction
		 * @return void
		 */
        public function ddwcwm_get_transaction_view_template( $transaction ) {

            if ( ! is_admin() ) {
                wp_enqueue_style( 'ddwcwm-front-style' );
            }

            if ( ! empty( $transaction[ 'sender_id' ] ) ) {
                $sender_id    = $transaction[ 'sender_id' ];
                $sender       = get_user_by( 'ID', $sender_id );
                $sender_email = ! empty( $sender ) && is_object( $sender ) ? $sender->user_email . ' (#' . $sender_id . ')' : '#' . $sender_id;
                $sender_url = ! empty( $sender->user_email ) && is_email( $sender->user_email ) ? 'mailto:' . $sender->user_email : '#';
            }

            $customer_id    = $transaction[ 'user_id' ];
            $customer       = get_user_by( 'ID', $customer_id );
            $customer_email = ! empty( $customer ) && is_object( $customer ) ? $customer->user_email . ' (#' . $customer_id . ')' : '#' . $customer_id;
            $order_id       = $transaction[ 'order_id' ];
            $order_currency = get_post_meta( $order_id, '_order_currency', true );
            $order_currency = apply_filters( 'ddwcwm_modify_transaction_currency', $order_currency, $order_id, $transaction );

            $transaction_type      = $transaction[ 'type' ];
            $transaction_reference = $transaction[ 'reference' ];

            ob_start();
            if ( $transaction_type == 'credit' || $transaction_reference == 'withdraw_cancelled' ) {
                ?>
                <span class="ddwcwm-credit">+<?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                <?php
            } else if ( $transaction_reference == 'withdraw_completed' ) {
                ?>
                <span class="ddwcwm-complete"><?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                <?php
            } else if ( $transaction_type == 'transfer' ) {
                $sender_id = $transaction[ 'sender_id' ];
                $user_id = get_current_user_id();
                if ( $user_id == $sender_id ) {
                    ?>
                    <span class="ddwcwm-debit">-<?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                    <?php
                } else {
                    ?>
                    <span class="ddwcwm-credit">+<?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                    <?php
                }
                ?>
                <?php
            } else if ( $transaction_type == 'debit' || $transaction_type == 'withdraw' ) {
                ?>
                <span class="ddwcwm-debit">-<?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                <?php
            }
            $amount = ob_get_contents();
            ob_end_clean();

            ?>
            <div class="wrap">
                <h1 class="wp-heading-inline"><?php esc_html_e( 'Transaction Details', 'ddwc-wallet-management' ); ?></h1>
                <?php
                $customer_url = ! empty( $customer->user_email ) && is_email( $customer->user_email ) ? 'mailto:' . $customer->user_email : '#';

                if ( is_admin() ) {
                    $customer_url = admin_url( 'user-edit.php?user_id=' . $customer_id );
                    if ( ! empty( $sender_url ) ) {
                        $sender_url = admin_url( 'user-edit.php?user_id=' . $sender_id );
                    }
                    ?>
                    <a href="<?php echo esc_url( admin_url( 'admin.php?page=' . $_GET[ 'page' ] ) ); ?>" class="page-title-action"><?php esc_html_e( 'Back', 'ddwc-wallet-management' ); ?></a>
					<hr class="wp-header-end" />
                    <?php
                }
                ?>
                <div class="ddwcwm-transaction-details-wrapper">
                    <table class="widefat fixed ddwcwm-transaction-details-table">
                        <tbody>
                            <tr valign="middle">
                                <th scope="row" class="titledesc"><strong><?php esc_html_e( 'Amount', 'ddwc-wallet-management' ); ?></strong></th>
                                <td class="forminp forminp-text"><?php echo wp_kses_post( $amount ); ?></td>
                            </tr>
                            <?php
                            if ( ! empty( $transaction[ 'order_id' ] ) ) {
                                $order_id  = $transaction[ 'order_id' ];
                                if ( is_admin() ) {
                                    $order_url = get_edit_post_link( $order_id );
                                } else {
                                    $order = wc_get_order( $order_id );
                                    $order_url = ! empty( $order ) && is_object( $order ) ? $order->get_view_order_url() : '#';
                                }
                                ?>
                                <tr valign="middle">
                                    <th scope="row" class="titledesc"><strong><?php esc_html_e( 'Order ID', 'ddwc-wallet-management' ); ?></strong></th>
                                    <td class="forminp forminp-text"><a href="<?php echo esc_url( $order_url ); ?>">#<?php echo esc_html( $order_id ); ?></a></td>
                                </tr>
                                <?php 
                            }
                            ?>
                            <tr valign="middle">
                                <th scope="row" class="titledesc"><strong><?php esc_html_e( 'Type', 'ddwc-wallet-management' ); ?></strong></th>
                                <td class="forminp forminp-text"><?php echo esc_html( DDWCWM_Transactions_Helper::ddwcwm_get_transactions_translation( $transaction_type ) ); ?></td>
                            </tr>
                            <tr valign="middle">
                                <th scope="row" class="titledesc"><strong><?php esc_html_e( 'Reference', 'ddwc-wallet-management' ); ?></strong></th>
                                <td class="forminp forminp-text"><?php echo esc_html( DDWCWM_Transactions_Helper::ddwcwm_get_transactions_translation( $transaction_reference ) ); ?></td>
                            </tr>
                            <?php
                            if ( ! empty( $sender_email ) ) {
                                ?>
                                <tr valign="middle">
                                    <th scope="row" class="titledesc"><strong><?php esc_html_e( 'Sender', 'ddwc-wallet-management' ); ?></strong></th>
                                    <td class="forminp forminp-text"><a href="<?php echo esc_url( $sender_url ); ?>"><?php echo esc_html( $sender_email ); ?></a></td>
                                </tr>
                                <?php
                            }
                            ?>
                            <tr valign="middle">
                                <th scope="row" class="titledesc"><strong><?php esc_html_e( 'Customer', 'ddwc-wallet-management' ); ?></strong></th>
                                <td class="forminp forminp-text"><a href="<?php echo esc_url( $customer_url ); ?>"><?php echo esc_html( $customer_email ); ?></a></td>
                            </tr>
                            <tr valign="middle">
                                <th scope="row" class="titledesc"><strong><?php esc_html_e( 'Date', 'ddwc-wallet-management' ); ?></strong></th>
                                <td class="forminp forminp-text"><?php echo esc_html( date_i18n( 'F d, Y g:i:s A', strtotime( $transaction[ 'date' ] ) ) ); ?></td>
                            </tr>
                            <tr valign="middle">
                                <th scope="row" class="titledesc"><strong><?php esc_html_e( 'Note', 'ddwc-wallet-management' ); ?></strong></th>
                                <td class="forminp forminp-text"><?php echo esc_html( $transaction[ 'note' ] ? stripslashes( $transaction[ 'note' ] ) : esc_html__( 'N/A', 'ddwc-wallet-management' ) ); ?></td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>
            <?php
        }
	}
}
