<?php
/**
 * Wallet Checkout Template Class
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

namespace DDWCWalletManagement\Templates\Front\Checkout;

use DDWCWalletManagement\Helper\Rules\DDWCWM_Rules_Helper;
use DDWCWalletManagement\Helper\Users\DDWCWM_Users_Helper;

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'DDWCWM_Wallet_Checkout_Template' ) ) {
    /**
     * Wallet Checkout Template Class
	 */
	class DDWCWM_Wallet_Checkout_Template {

        /**
         * User Helper variable
         *
         * @var object
         */
        protected $user_helper;

        /**
         * User Helper variable
         *
         * @var object
         */
        protected $rules_helper;

        /**
		 * Construct
		 */
		public function __construct() {
            $this->user_helper = new DDWCWM_Users_Helper();
            $this->rules_helper = new DDWCWM_Rules_Helper();
            $this->ddwcwm_get_wallet_checkout_template();
        }

        /**
		 * Get Wallet Checkout Template function
		 *
		 * @return void
		 */
        public function ddwcwm_get_wallet_checkout_template() {
            global $ddwcwm_wallet;

            $cart_total = apply_filters( 'ddwcwm_modify_amount_to_base_currency', WC()->cart->total );

            if ( 'percentage' === $ddwcwm_wallet[ 'debit_limit_type' ] ) {
                $ddwcwm_wallet[ 'min_debit_limit' ] = floatval( $ddwcwm_wallet[ 'min_debit_limit' ] ) * floatval( $cart_total ) / 100;
                $ddwcwm_wallet[ 'max_debit_limit' ] = floatval( $ddwcwm_wallet[ 'max_debit_limit' ] ) * floatval( $cart_total ) / 100;
            }

            $cart_contents     = WC()->cart->get_cart_contents();
            $wallet_topup_pro  = get_page_by_path( 'ddwcwm-wallet-topup' , OBJECT, 'product' );
            $wallet_pro_exists = false;

			if ( ! empty( $cart_contents ) ) {
				foreach ( $cart_contents as $key => $cart_content ) {
                    $product_id = ! empty( $cart_content[ 'variation_id' ] ) ? $cart_content[ 'variation_id' ] : $cart_content[ 'product_id' ];

					if ( $product_id == $wallet_topup_pro->ID ) {
                        $wallet_pro_exists = true;
                        break;
					}
                }
            }

            $user_wallet_balance = $this->user_helper->ddwcwm_get_user_wallet_balance();
            $cashbacks           = $this->rules_helper->ddwcwm_calculate_cashbacks_with_cart();
            $total_cashback      = $cashbacks[ 'cart' ] + $cashbacks[ 'topup' ] + $cashbacks[ 'product' ];
            $total_cashback      = apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $total_cashback );

            if ( ! empty( $total_cashback ) ) {
                ob_start();
                ?>
                <span><?php echo wc_price( $total_cashback ); ?></span>
                <?php
                $cashback_amount_html = ob_get_contents();
                ob_end_clean();
                ?>
                <tr>
                    <td colspan="2" class="ddwcwm-awarded-cashback-info-td">
                        <div class="woocommerce-info ddwcwm-awarded-cashback-info">
                            <i><?php echo sprintf( esc_html__( 'You\'ll get awarded by %s cashback amount in your wallet after the completion of current purchase.', 'ddwc-wallet-management' ), $cashback_amount_html ); ?></i>
                        </div>
                    </td>
                </tr>
                <?php
            }

            if ( apply_filters( 'ddwcwm_custom_check_for_wallet_partial_payment_display', false ) || ( ! $wallet_pro_exists && ! empty( $ddwcwm_wallet[ 'partial_payments_enabled' ] ) && ! empty( $user_wallet_balance ) && ( $cart_total > $user_wallet_balance || ( ! empty( $ddwcwm_wallet[ 'max_debit_limit' ] ) && $ddwcwm_wallet[ 'max_debit_limit' ] < $cart_total ) ) && ( empty( $ddwcwm_wallet[ 'min_debit_limit' ] ) || $ddwcwm_wallet[ 'min_debit_limit' ] < $user_wallet_balance ) ) ) {
                wp_enqueue_style( 'ddwcwm-front-style' );
                wp_enqueue_script( 'ddwcwm-front-script' );

                $disabled = ! empty( WC()->session->get( 'ddwcwm_wallet_amount' ) ) ? 'disabled' : '';
                ?>
                <tr>
                    <td colspan="2" class="ddwcwm-wallet-checkout-container-td">
                        <div class="ddwcwm-wallet-checkout-container">
                            <?php
                            if ( apply_filters( 'ddwcwm_show_available_balance_in_partial_payment', true ) ) {
                                ?>
                                <p><strong><?php esc_html_e( 'Your Wallet Balance:', 'ddwc-wallet-management' ); ?></strong> <span><?php echo wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $user_wallet_balance ) ); ?></span></p>
                                <?php
                            }
                            ?>
                            <?php
                            if ( ! empty( $ddwcwm_wallet[ 'max_debit_limit' ] ) ) {
                                ?>
                                <p><strong><?php esc_html_e( 'Max Debit Limit:', 'ddwc-wallet-management' ); ?></strong> <span><?php echo wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'max_debit_limit' ] ) ); ?></span></p>
                                <?php
                            }
                            ?>
                            <p><i><?php esc_html_e( 'Your wallet doesn\'t have enough money or cart total is greater than the maximum debit amount. But you can use wallet as partial payment then use below methods for rest payment.', 'ddwc-wallet-management' ); ?></i></p>
                            <button id="ddwcwm-use-wallet-button" <?php echo esc_attr( $disabled ); ?>><?php esc_html_e( 'Use Wallet', 'ddwc-wallet-management' ); ?></button>
                        </div>
                    </td>
                </tr>
                <?php
            }
        }
    }
}
