<?php
/**
 * Wallet Operations Shortcode
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit();

global $ddwcwm_wallet;

?>
<div class="ddwcwm-wallet-operations-wrapper">

    <div class="ddwcwm-wallet-topup-wrapper">
        <div>
            <label for="ddwcwm-wallet-topup-amount">
                <img src="<?php echo esc_url( DDWCWM_PLUGIN_URL . 'assets/images/wallet-topup.png' ); ?>" />
                <p><?php esc_html_e( 'Add Money', 'ddwc-wallet-management' ); ?></p>
            </label>
        </div>
        <form method="post">
            <?php
            wp_nonce_field( 'ddwcwm_wallet_topup_nonce_action', 'ddwcwm_wallet_topup_nonce' );
            ?>
            <div class="ddwcwm-wallet-topup-input-container">
                <input type="number" class="form-control" id="ddwcwm-wallet-topup-amount" name="ddwcwm_wallet_topup_amount" min="0" step="0.01" placeholder="<?php esc_attr_e( 'Enter amount', 'ddwc-wallet-management' ); ?>" />
                <button type="submit" class="button" name="ddwcwm_wallet_topup"><?php esc_html_e( 'Topup', 'ddwc-wallet-management' ); ?></button>
            </div>
        </form>
    </div>

    <?php
    $template_columns = 2;
    if ( ! empty( $ddwcwm_wallet[ 'withdrawals_enabled' ] ) ) {
        $template_columns++;
    }
    if ( ! empty( $ddwcwm_wallet[ 'referrals_enabled' ] ) ) {
        $template_columns++;
    }
    if ( $template_columns == 4 ) {
        $grid_style = "grid-template-columns: repeat(2, 1fr); padding: 10px 0; grid-gap: 10px";
    } else {
        $grid_style = "grid-template-columns: repeat($template_columns, 1fr);";
    }
    ?>

    <div class="ddwcwm-wallet-operations" style="<?php echo esc_attr( $grid_style ); ?>">
        <a href="#" data-operation="send">
            <img src="<?php echo esc_url( DDWCWM_PLUGIN_URL . 'assets/images/wallet-send.png' ); ?>" />
            <p><?php esc_html_e( 'Send Money', 'ddwc-wallet-management' ); ?></p>
        </a>
        <a href="#" data-operation="request">
            <img src="<?php echo esc_url( DDWCWM_PLUGIN_URL . 'assets/images/wallet-request.png' ); ?>" />
            <p><?php esc_html_e( 'Request Money', 'ddwc-wallet-management' ); ?></p>
        </a>
        <?php
        if ( ! empty( $ddwcwm_wallet[ 'withdrawals_enabled' ] ) ) {
            ?>
            <a href="#" data-operation="withdraw">
                <img src="<?php echo esc_url( DDWCWM_PLUGIN_URL . 'assets/images/wallet-withdraw.png' ); ?>" />
                <p><?php esc_html_e( 'Withdraw Money', 'ddwc-wallet-management' ); ?></p>
            </a>
            <?php
        }
        if ( ! empty( $ddwcwm_wallet[ 'referrals_enabled' ] ) ) {
            ?>
            <a href="#" data-operation="refer">
                <img src="<?php echo esc_url( DDWCWM_PLUGIN_URL . 'assets/images/wallet-refer.png' ); ?>" />
                <p><?php esc_html_e( 'Refer', 'ddwc-wallet-management' ); ?></p>
            </a>
            <?php
        }
        ?>
    </div>

    <div class="ddwcwm-wallet-operation-popup" id="ddwcwm-wallet-send-money-popup">
        <div class="ddwcwm-wallet-operation-popup-content">
            <form method="post" id="ddwcwm-send-money-form">
                <h3><?php esc_html_e( 'Send Money', 'ddwc-wallet-management' ); ?></h3>
                <span class="ddwcwm-close-popup"></span>
                <div class="ddwcwm-message"></div>
                <table>
                    <tbody>
                        <tr>
                            <td>
                                <label for="ddwcwm-email"><?php esc_html_e( 'Receiver\'s Email', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <input type="email" class="form-control" name="ddwcwm_email" id="ddwcwm-email" placeholder="<?php esc_attr_e( 'Enter Email', 'ddwc-wallet-management' ); ?>" required>
                            </td>
                        </tr>
                        <tr>
                            <td>
                                <label for="ddwcwm-amount"><?php esc_html_e( 'Amount', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <input type="number" min="<?php echo esc_attr( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', ! empty( $ddwcwm_wallet[ 'min_transfer_limit' ] ) ? $ddwcwm_wallet[ 'min_transfer_limit' ] : 0 ) ); ?>" step="0.01" max="<?php echo esc_attr( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'max_transfer_limit' ] ) ); ?>" class="form-control" name="ddwcwm_amount" id="ddwcwm-amount" placeholder="<?php esc_attr_e( 'Enter Amount', 'ddwc-wallet-management' ); ?>" required>
                                <?php
                                if ( ! empty( $ddwcwm_wallet[ 'min_transfer_limit' ] ) ) {
                                    ?>
                                    <p class="ddwcwm-description"><?php echo sprintf( esc_html__( 'Min Transfer Limit is %s', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'min_transfer_limit' ] ) ) ); ?></p>
                                    <?php
                                }
                                if ( ! empty( $ddwcwm_wallet[ 'max_transfer_limit' ] ) ) {
                                    ?>
                                    <p class="ddwcwm-description"><?php echo sprintf( esc_html__( 'Max Transfer Limit is %s', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'max_transfer_limit' ] ) ) ); ?></p>
                                    <?php
                                }
                                ?>
                            </td>
                        </tr>
                        <tr>
                            <td>
                                <label for="ddwcwm-note"><?php esc_html_e( 'Note', 'ddwc-wallet-management' ); ?></label>
                            </td>
                            <td>
                                <textarea class="form-control" name="ddwcwm_note" id="ddwcwm-note" placeholder="<?php esc_attr_e( 'Enter Note', 'ddwc-wallet-management' ); ?>"></textarea>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <input type="hidden" class="form-control" id="ddwcwm-otp-verification-done" name="ddwcwm_otp_verification_done" value="<?php echo esc_attr( in_array( 'send', $ddwcwm_wallet[ 'enabled_otp_operations' ] ) ? '' : 'done' ); ?>">
                <input type="submit" class="button alt" id="ddwcwm-send-money-submit" name="ddwcwm_send_money_submit" value="<?php esc_attr_e( 'Send Money', 'ddwc-wallet-management' ); ?>">
            </form>
            <form method="post" id="ddwcwm-verify-otp-form">
                <h3><?php esc_html_e( 'Verify OTP', 'ddwc-wallet-management' ); ?></h3>
                <span class="ddwcwm-close-popup"></span>
                <div class="ddwcwm-message"></div>
                <?php do_action( 'ddwcwm_add_content_after_message_in_otp_form' ); ?>
                <table>
                    <tbody>
                        <tr>
                            <td>
                                <label for="ddwcwm-otp"><?php esc_html_e( 'OTP', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <input type="number" class="form-control" name="ddwcwm_otp" id="ddwcwm-otp" placeholder="<?php esc_attr_e( 'Enter OTP', 'ddwc-wallet-management' ); ?>" required>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <input type="submit" class="button alt" id="ddwcwm-verify-otp-submit" name="ddwcwm_verify_otp_submit" value="<?php esc_attr_e( 'Verify OTP', 'ddwc-wallet-management' ); ?>">
            </form>
        </div>
    </div>

    <div class="ddwcwm-wallet-operation-popup" id="ddwcwm-wallet-request-money-popup">
        <div class="ddwcwm-wallet-operation-popup-content">
            <form method="post" id="ddwcwm-request-money-form">
                <h3><?php esc_html_e( 'Request Money', 'ddwc-wallet-management' ); ?></h3>
                <span class="ddwcwm-close-popup"></span>
                <div class="ddwcwm-message"></div>
                <table>
                    <tbody>
                        <tr>
                            <td>
                                <label for="ddwcwm-email"><?php esc_html_e( 'Customer\'s Email', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <input type="email" class="form-control" name="ddwcwm_email" id="ddwcwm-email" placeholder="<?php esc_attr_e( 'Enter Email', 'ddwc-wallet-management' ); ?>" required>
                            </td>
                        </tr>
                        <tr>
                            <td>
                                <label for="ddwcwm-amount"><?php esc_html_e( 'Amount', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <input type="number" min="<?php echo esc_attr( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', ! empty( $ddwcwm_wallet[ 'min_transfer_limit' ] ) ? $ddwcwm_wallet[ 'min_transfer_limit' ] : 0 ) ); ?>" step="0.01" max="<?php echo esc_attr( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'max_transfer_limit' ] ) ); ?>" class="form-control" name="ddwcwm_amount" id="ddwcwm-amount" placeholder="<?php esc_attr_e( 'Enter Amount', 'ddwc-wallet-management' ); ?>" required>
                                <?php
                                if ( ! empty( $ddwcwm_wallet[ 'min_transfer_limit' ] ) ) {
                                    ?>
                                    <p class="ddwcwm-description"><?php echo sprintf( esc_html__( 'Min Request Limit is %s', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'min_transfer_limit' ] ) ) ); ?></p>
                                    <?php
                                }
                                if ( ! empty( $ddwcwm_wallet[ 'max_transfer_limit' ] ) ) {
                                    ?>
                                    <p class="ddwcwm-description"><?php echo sprintf( esc_html__( 'Max Request Limit is %s', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'max_transfer_limit' ] ) ) ); ?></p>
                                    <?php
                                }
                                ?>
                            </td>
                        </tr>
                        <tr>
                            <td>
                                <label for="ddwcwm-note"><?php esc_html_e( 'Note', 'ddwc-wallet-management' ); ?></label>
                            </td>
                            <td>
                                <textarea class="form-control" name="ddwcwm_note" id="ddwcwm-note" placeholder="<?php esc_attr_e( 'Enter Note', 'ddwc-wallet-management' ); ?>"></textarea>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <input type="hidden" class="form-control" id="ddwcwm-otp-verification-done" name="ddwcwm_otp_verification_done" value="<?php echo esc_attr( in_array( 'request', $ddwcwm_wallet[ 'enabled_otp_operations' ] ) ? '' : 'done' ); ?>">
                <input type="submit" class="button alt" id="ddwcwm-request-money-submit" name="ddwcwm_request_money_submit" value="<?php esc_attr_e( 'Request Money', 'ddwc-wallet-management' ); ?>">
            </form>
            <form method="post" id="ddwcwm-verify-otp-form">
                <h3><?php esc_html_e( 'Verify OTP', 'ddwc-wallet-management' ); ?></h3>
                <span class="ddwcwm-close-popup"></span>
                <div class="ddwcwm-message"></div>
                <?php do_action( 'ddwcwm_add_content_after_message_in_otp_form' ); ?>
                <table>
                    <tbody>
                        <tr>
                            <td>
                                <label for="ddwcwm-otp"><?php esc_html_e( 'OTP', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <input type="number" class="form-control" name="ddwcwm_otp" id="ddwcwm-otp" placeholder="<?php esc_attr_e( 'Enter OTP', 'ddwc-wallet-management' ); ?>" required>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <input type="submit" class="button alt" id="ddwcwm-verify-otp-submit" name="ddwcwm_verify_otp_submit" value="<?php esc_attr_e( 'Verify OTP', 'ddwc-wallet-management' ); ?>">
            </form>
        </div>
    </div>

    <div class="ddwcwm-wallet-operation-popup" id="ddwcwm-wallet-withdraw-money-popup">
        <div class="ddwcwm-wallet-operation-popup-content">
            <form method="post" id="ddwcwm-withdraw-money-form">
                <h3><?php esc_html_e( 'Withdraw Money', 'ddwc-wallet-management' ); ?></h3>
                <span class="ddwcwm-close-popup"></span>
                <div class="ddwcwm-message"></div>
                <?php
                if ( apply_filters( 'ddwcwm_show_withdraw_money_fields', true ) ) {
                    ?>
                    <table>
                        <tbody>
                            <tr>
                                <td>
                                    <label for="ddwcwm-amount"><?php esc_html_e( 'Amount', 'ddwc-wallet-management' ); ?>
                                        <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                    </label>
                                </td>
                                <td>
                                    <input type="number" min="<?php echo esc_attr( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', ! empty( $ddwcwm_wallet[ 'min_withdrawal_limit' ] ) ? $ddwcwm_wallet[ 'min_withdrawal_limit' ] : 0 ) ); ?>" step="0.01" max="<?php echo esc_attr( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'max_withdrawal_limit' ] ) ); ?>" class="form-control" name="ddwcwm_amount" id="ddwcwm-amount" placeholder="<?php esc_attr_e( 'Enter Amount', 'ddwc-wallet-management' ); ?>" required>
                                    <?php
                                    if ( ! empty( $ddwcwm_wallet[ 'min_withdrawal_limit' ] ) ) {
                                        ?>
                                        <p class="ddwcwm-description"><?php echo sprintf( esc_html__( 'Min Withdrawal Limit is %s', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'min_withdrawal_limit' ] ) ) ); ?></p>
                                        <?php
                                    }
                                    if ( ! empty( $ddwcwm_wallet[ 'max_withdrawal_limit' ] ) ) {
                                        ?>
                                        <p class="ddwcwm-description"><?php echo sprintf( esc_html__( 'Max Withdrawal Limit is %s', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'max_withdrawal_limit' ] ) ) ); ?></p>
                                        <?php
                                    }
                                    if ( ! empty( $ddwcwm_wallet[ 'withdraw_charges_amount' ] ) ) {
                                        if ( $ddwcwm_wallet[ 'withdraw_charges_type' ] == 'fixed' ) {
                                            $charges = wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'withdraw_charges_amount' ] ) );
                                        } else if ( $ddwcwm_wallet[ 'withdraw_charges_type' ] == 'percentage' ) {
                                            $charges = $ddwcwm_wallet[ 'withdraw_charges_amount' ] . '%';
                                        }
                                        ?>
                                        <p class="ddwcwm-description"><?php echo sprintf( esc_html__( 'Withdrawal Charge is %s.', 'ddwc-wallet-management' ), $charges ); ?></p>
                                        <?php
                                    }
                                    ?>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    <label for="ddwcwm-note"><?php esc_html_e( 'Note', 'ddwc-wallet-management' ); ?>
                                        <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                    </label>
                                </td>
                                <td>
                                    <textarea class="form-control" name="ddwcwm_note" id="ddwcwm-note" placeholder="<?php esc_attr_e( 'Enter Note', 'ddwc-wallet-management' ); ?>" required></textarea>
                                    <p class="ddwcwm-description"><?php esc_html_e( 'Payment details for the admin to process the amount. ex - paypal mail id', 'ddwc-wallet-management' ); ?></p>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                    <input type="hidden" class="form-control" id="ddwcwm-otp-verification-done" name="ddwcwm_otp_verification_done" value="<?php echo esc_attr( in_array( 'withdraw', $ddwcwm_wallet[ 'enabled_otp_operations' ] ) ? '' : 'done' ); ?>">
                    <input type="submit" class="button alt" id="ddwcwm-withdraw-money-submit" name="ddwcwm_withdraw_money_submit" value="<?php esc_attr_e( 'Withdraw Money', 'ddwc-wallet-management' ); ?>">
                    <?php
                } else {
                    do_action( 'ddwcwm_withdraw_money_fields_message' );
                }
                ?>
            </form>
            <form method="post" id="ddwcwm-verify-otp-form">
                <h3><?php esc_html_e( 'Verify OTP', 'ddwc-wallet-management' ); ?></h3>
                <span class="ddwcwm-close-popup"></span>
                <div class="ddwcwm-message"></div>
                <?php do_action( 'ddwcwm_add_content_after_message_in_otp_form' ); ?>
                <table>
                    <tbody>
                        <tr>
                            <td>
                                <label for="ddwcwm-otp"><?php esc_html_e( 'OTP', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <input type="number" class="form-control" name="ddwcwm_otp" id="ddwcwm-otp" placeholder="<?php esc_attr_e( 'Enter OTP', 'ddwc-wallet-management' ); ?>" required>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <input type="submit" class="button alt" id="ddwcwm-verify-otp-submit" name="ddwcwm_verify_otp_submit" value="<?php esc_attr_e( 'Verify OTP', 'ddwc-wallet-management' ); ?>">
            </form>
        </div>
    </div>

    <div class="ddwcwm-wallet-operation-popup" id="ddwcwm-wallet-refer-popup">
        <div class="ddwcwm-wallet-operation-popup-content">
            <form method="post" id="ddwcwm-wallet-refer-form">
                <h3><?php esc_html_e( 'Refer', 'ddwc-wallet-management' ); ?></h3>
                <span class="ddwcwm-close-popup"></span>
                <div class="ddwcwm-message"></div>
                <?php
                if ( ! empty( $ddwcwm_wallet[ 'referral_earning_amount' ] ) ) {
                    wc_print_notice( sprintf( esc_html__( 'You and your friend both will get %s on your wallets after your friend registers.', 'ddwc-wallet-management' ), wc_price( apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $ddwcwm_wallet[ 'referral_earning_amount' ] ) ) ), 'notice' );
                }
                ?>
                <table>
                    <tbody>
                        <tr>
                            <td>
                                <label for="ddwcwm-email"><?php esc_html_e( 'User\'s Email', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <input type="email" class="form-control" name="ddwcwm_email" id="ddwcwm-email" placeholder="<?php esc_attr_e( 'Enter Email', 'ddwc-wallet-management' ); ?>" required>
                            </td>
                        </tr>
                        <tr>
                            <td>
                                <label for="ddwcwm-message"><?php esc_html_e( 'Message', 'ddwc-wallet-management' ); ?>
                                    <abbr class="required" title="<?php esc_attr_e( 'Required', 'ddwc-wallet-management' ); ?>">*</abbr>
                                </label>
                            </td>
                            <td>
                                <textarea class="form-control" name="ddwcwm_message" id="ddwcwm-message" placeholder="<?php esc_attr_e( 'Enter Message', 'ddwc-wallet-management' ); ?>" rows="4"><?php echo esc_html( $ddwcwm_wallet[ 'referral_email_content' ] ); ?></textarea>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <input type="submit" class="button alt" id="ddwcwm-wallet-refer-submit" name="ddwcwm_wallet_refer_submit" value="<?php esc_attr_e( 'Refer', 'ddwc-wallet-management' ); ?>">
            </form>
        </div>
    </div>

</div>
